#R code for the Maseyk et al. (in prep.)
#Written by Anna M Csergo, Trinity College Dublin, Ireland, in 2016
#Contact: http://annamariacsergo.weebly.com

R version 3.2.3 (2015-12-10)
Platform: x86_64-apple-darwin13.4.0 (64-bit)
Running under: OS X 10.9.5 (Mavericks)


setwd("/Users/annamariacsergo/Dropbox/Ecos_Services")#for Mac

#Packages for Modeling
library(nlme)#Version ‘3.1.125’; for mixed effects model
library(car)# Version ‘2.1.1’; for robust anova on mixed effects model
library(multcomp)# Version ‘1.4.4’; Tukey's HSD posthoc comparison on anova
library(RLRsim)#Version ‘3.1.2’; likelihood ratio test for linear mixed models
library(ape)# for testing spatial autocorrelation in residuals

#Packages for plotting
library(ggplot2)# Version ‘2.1.0’; for plotting violinplots
library(gridExtra)# Version ‘2.2.1’; for arranging multiple plots on one page

#Other packages
library(psych)#Version ‘1.5.8’; for good descriptive statistics
library(reshape)#Version ‘0.8.5’; for merging columns of a df
library(plyr)#Version ‘1.8.3’; for renaming dataframe column namesß
 

#Reason for robust ANOVA used.
#Hypothesis testing is the wrong tool to use to asses the validity of model assumptions. If the sample size is small, you have no power #to detect any variance differences, even if the variance differences are large. If you have a large sample size you have power to #detect even the most trivial deviations from equal variance, so you will almost always reject the null. Simulation studies have shown #that preliminary testing of model assumption leads to unreliable type I errors.
#Looking at the residuals across all cells is a good indicator, or if your data are normal, you can use the AIC or BIC with/without #equal variances as a selection procedure.
#If you think there are unequal variances, drop the assumption with something like:
#library(car)
#model.lm <- lm(formula=x ~ g1 + g2 + g1*g2,data=dat,na.action=na.omit)
#Anova(model.lm,type='II',white.adjust='hc3')
#You don't loose much power with the robust method (hetroscedastic consistent covariance matrices), so if in doubt go robust.



#descriptive statistics (means, SD, etc.)
Count<-read.csv("/Users/annamariacsergo/Dropbox/Ecos_Services/Data/Count.csv",stringsAsFactors=FALSE)#read data
Count$plot = with(Count, interaction(Site, Land.use))#make a new categorical variable for random effect
attach(Count)
cover <- describeBy(Count, group=plot)
describeBy(Count, group=Land.use)
describeBy(Count, group=Site)
aggregate(Total, by=list(Land.use,Site), FUN=sd)
aggregate(Total, by=list(Land.use,Site), FUN=mean)


Cover<-read.csv("/Users/annamariacsergo/Dropbox/Ecos_Services/Data/Cover.csv",stringsAsFactors=FALSE)#read data
Cover$plot <- with(Cover, interaction(Site, Land.use))
attach(Cover)
cover <- describeBy(Cover, group=plot)
describeBy(Cover, group=Land.use)
describeBy(Cover, group=Site)
aggregate(Total, by=list(Land.use,Site), FUN=sd)
aggregate(Total, by=list(Land.use,Site), FUN=mean)


Evar<-read.csv("/Users/annamariacsergo/Dropbox/Ecos_Services/Data/Evar.csv",stringsAsFactors=FALSE)#read data
Evar$plot <- with(Evar, interaction(Site, Land.use))
attach(Evar)
evar <- describeBy(Evar, group=plot)
describeBy(Evar, group=Land.use)
describeBy(Evar, group=Site)
aggregate(Evar $Total, by=list(Evar $Land.use* Evar $Site), FUN=mean)
aggregate(Evar $Total, by=list(Evar $Land.use* Evar $Site), FUN=sd)


invSimpson<-read.csv("/Users/annamariacsergo/Dropbox/Ecos_Services/Data/InvSimpson.csv",stringsAsFactors=FALSE)#read data
invSimpson$plot <- with(invSimpson, interaction(Site, Land.use))
attach(invSimpson)

invSimp <- describeBy(invSimpson, group=plot)
describeBy(invSimpson, group=Land.use)
describeBy(invSimpson, group=Site)
aggregate(invSimpson$Total, by=list(invSimpson$Land.use,invSimpson $Site), FUN=mean)
aggregate(invSimpson$Total, by=list(invSimpson$Land.use,invSimpson $Site), FUN=sd)




#====Linear mixed effects model and Two-Way robust ANOVA with post-hoc Tukey Test======

#COUNT DATA
#==========
Data<-read.csv("~/Dropbox/Ecos_Services/Data/Count.csv",stringsAsFactors=TRUE)#read data
Data$plot = with(Data, interaction(Site, Land.use))#make a new categorical variable for random effect


pdf(paste("./Stats/Results/","Count.pdf",sep=""),width=11.7,height=8.3)
#Total species
mod1<-lme(Total ~ Land.use+Site, random= ~1|plot, data=Data)
plot(mod1,main="Total")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
Data$residuals_total <- resids 
dists <- as.matrix(dist(cbind(Data$Lon, Data$Lat)))#create distance matrix
dist.inv <- 1/dists #inverse of distances
diag(dist.inv) <- 0 #set diagonal to 0
Moran.I(Data$residuals_total, dist.inv)# zero autocorrelation (p=0.315)

#Fodder providers
mod1<-lme(Fodder ~ Land.use+Site, random= ~1|plot, data=Data)
plot(mod1,main="Fodder")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
Data$residuals_fodder <- resids 
Moran.I(Data$residuals_fodder, dist.inv)# zero autocorrelation (p=0.442)


#Medicinal
mod1<-lme(Medic ~ Land.use+Site, random= ~1|plot, data=Data)
plot(mod1,main="Medicinal")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
Data$residuals_medic <- resids 
Moran.I(Data$residuals_medic, dist.inv)# zero autocorrelation (p=0.053)


#Meliferous
mod1<-lme(Melif ~ Land.use+Site, random= ~1|plot, data=Data)
plot(mod1,main="Meliferous")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
Data$residuals_melif <- resids 
Moran.I(Data$residuals_melif, dist.inv)# zero autocorrelation (p=0.557)


#Nitrogen fixers
mod1<-lme(Nfix ~ Land.use+Site, random= ~1|plot, data=Data)
plot(mod1,main="Nfix")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
Data$residuals_nfix <- resids 
Moran.I(Data$residuals_nfix, dist.inv)# zero autocorrelation (p=0.844)


#Conservation concern
mod1<-lme(Prot ~ Land.use+Site, random= ~1|plot, data=Data)
plot(mod1,main="Protected")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
Data$residuals_prot <- resids 
Moran.I(Data$residuals_prot, dist.inv)# zero autocorrelation (p=0.960)


#Pollen providers
mod1<-lme(Pollen ~ Land.use+Site, random= ~1|plot, data=Data)
plot(mod1,main="Pollen")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
Data$residuals_pollen <- resids 
Moran.I(Data$residuals_pollen, dist.inv)# zero autocorrelation (p=0.066)

dev.off()



#RELATIVE COVER 
#===============

DataCov<-read.csv("/Users/annamariacsergo/Dropbox/Ecos_Services/Data/Cover.csv",stringsAsFactors=TRUE)#read data
DataCov$plot = with(DataCov, interaction(Site, Land.use))#make a new categorical variable for random effect

#logit transformation of relative cover data (as per Warton and Hui 2011 Ecology) (arcsine square root transformation is bad); except Protected species where we applied sqrt transformation because of many zero values an Pollen where log transformation worked better

pdf(paste("./Stats/Results/","Cover.pdf",sep=""),width=11.7,height=8.3)

#Total species
mod1<-lme(Total~Land.use + Site, random=~1|plot, data=DataCov)
plot(mod1,main="Total")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(DataCov$Land.use,DataCov$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataCov$residuals_total <- resids 
dists <- as.matrix(dist(cbind(DataCov$Lon, DataCov$Lat)))#create distance matrix
dist.inv <- 1/dists #inverse of distances
diag(dist.inv) <- 0 #set diagonal to 0
Moran.I(DataCov$residuals_total, dist.inv)# zero autocorrelation (p=0.801)


#Fodder providers
mod1<-lme(logit(Fodder)~Land.use + Site, random=~1|plot, data=DataCov)
plot(mod1,main="Fodder")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataCov$residuals_fodder <- resids 
Moran.I(DataCov$residuals_fodder, dist.inv)# zero autocorrelation (p=0.842)


#Medicinal
mod1<-lme(Medic~Land.use + Site, random=~1|plot, data=DataCov)
plot(mod1,main="Medicinal")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataCov$residuals_medic <- resids 
Moran.I(DataCov$residuals_medic, dist.inv)# zero autocorrelation (p=0.854)


#Meliferous
mod1<-lme(Melif~Land.use + Site, random=~1|plot, data=DataCov)
plot(mod1,main="Meliferous")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataCov$residuals_melif <- resids 
Moran.I(DataCov$residuals_melif, dist.inv)# zero autocorrelation (p=0.539)


#Nitrogen fixers
mod1<-lme(logit(Nfix)~Land.use + Site, random=~1|plot, data=DataCov)
plot(mod1,main="N fixers")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataCov$residuals_nfix <- resids 
Moran.I(DataCov$residuals_nfix, dist.inv)# zero autocorrelation (p=0.681)


#Conservation concern
mod1<-lme(sqrt(Prot)~Land.use + Site, random=~1|plot, data=DataCov)
plot(mod1,main="Protected")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataCov$residuals_prot <- resids 
Moran.I(DataCov$residuals_prot, dist.inv)# spatial autocorrelation significant (p=0.018)
#re-run the model with spatial correlation structures
mod.prot <- update(mod1, correlation = corExp(1, form=~Lat+Lon), method="ML")#exponential correlation check
summary(mod.prot)
mod.prot <- update(mod1, correlation = corGaus(1, form=~Lat+Lon), method="ML")#Gaussian correlation check
summary(mod.prot)
#both correlation structures produce similar AIC (-85.96) which is lower than that of the main model (-65.48); report these corrected models but results didn't change but the effects became stronger
Anova(mod.prot,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod.prot, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod.prot, linfct = mcp(Site="Tukey")))



#Pollen providers
mod1<-lme(log(Pollen)~Land.use + Site, random=~1|plot, data=DataCov)#this is the best transformation to improve normality and homogeneity
plot(mod1,main="Pollen")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataCov$residuals_pollen <- resids 
Moran.I(DataCov$residuals_pollen, dist.inv)# zero autocorrelation (p=0.946)

dev.off()



#INVERSE SIMPSON DIVERSITY
#=========================
DataInvSimp<-read.csv("/Users/annamariacsergo/Dropbox/Ecos_Services/Data/InvSimpson.csv",stringsAsFactors=TRUE)#read data
DataInvSimp$plot = with(DataInvSimp, interaction(Site, Land.use))#make a new categorical variable for random effect


pdf(paste("./Stats/Results/","InverseSimpson.pdf",sep=""),width=11.7,height=8.3)

#Total species
mod1<-lme(Total~Land.use + Site, random=~1|plot, data=DataInvSimp)
plot(mod1,main="Total")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(DataInvSimp$Land.use,DataInvSimp$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataInvSimp$residuals_total <- resids 
dists <- as.matrix(dist(cbind(DataInvSimp$Lon, DataInvSimp$Lat)))#create distance matrix
dist.inv <- 1/dists #inverse of distances
diag(dist.inv) <- 0 #set diagonal to 0
Moran.I(DataInvSimp$residuals_total, dist.inv)# zero autocorrelation (p=0.189)


#Good fodder
mod1<-lme(log(Fodder)~Land.use + Site, random=~1|plot, data=DataInvSimp)
plot(mod1,main="Fodder")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataInvSimp$residuals_fodder <- resids 
Moran.I(DataInvSimp$residuals_fodder, dist.inv)# zero autocorrelation (p=0.575)


#Medicinal
mod1<-lme(Medic~Land.use + Site, random=~1|plot, data=DataInvSimp)
plot(mod1,main="Medic")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataInvSimp$residuals_medic <- resids 
Moran.I(DataInvSimp$residuals_medic, dist.inv)# zero autocorrelation (p=0.194)


#Meliferous
mod1<-lme(log(Melif)~Land.use + Site, random=~1|plot, data=DataInvSimp)
plot(mod1,main="Melif")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataInvSimp$residuals_melif <- resids 
Moran.I(DataInvSimp$residuals_melif, dist.inv)# zero autocorrelation (p=0.323)


#Nitrogen fixers
mod1<-lme(log(Nfix)~Land.use + Site, random=~1|plot, data=DataInvSimp)
plot(mod1,main="Nfix")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataInvSimp$residuals_nfix <- resids 
Moran.I(DataInvSimp$residuals_nfix, dist.inv)# zero autocorrelation (p=0.743)


#Conservation concern
mod1<-lme(Prot~Land.use + Site, random=~1|plot, data=DataInvSimp)
plot(mod1,main="Protected")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataInvSimp$residuals_prot <- resids 
Moran.I(DataInvSimp$residuals_prot, dist.inv)# zero autocorrelation (p=0.603)


#Pollen providers
mod1<-lme(log(Pollen)~Land.use + Site, random=~1|plot, data=DataInvSimp)
plot(mod1,main="Pollen")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataInvSimp$residuals_pollen <- resids 
Moran.I(DataInvSimp$residuals_pollen, dist.inv)# zero autocorrelation (p=0.213)


dev.off()

####=======================

# SPECIES EVENNESS
DataEvar<-read.csv("/Users/annamariacsergo/Dropbox/Ecos_Services/Data/Evar.csv",stringsAsFactors=TRUE)#read data
DataEvar$plot = with(DataEvar, interaction(Site, Land.use))#make a new categorical variable for random effect

pdf(paste("./Stats/Results/","Evenness.pdf",sep=""),width=11.7,height=8.3)

#Total
mod1<-lme(log(Total)~Land.use + Site, random=~1|plot, data=DataEvar)
plot(mod1,main="Fodder")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(DataEvar$Land.use,DataEvar$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataEvar$residuals_total <- resids 
dists <- as.matrix(dist(cbind(DataEvar$Lon, DataEvar$Lat)))#create distance matrix
dist.inv <- 1/dists #inverse of distances
diag(dist.inv) <- 0 #set diagonal to 0
Moran.I(DataEvar$residuals_total, dist.inv)# zero autocorrelation (p=0.209)



#Good fodder
mod1<-lme(log(Fodder)~Land.use + Site, random=~1|plot, data=DataEvar)
plot(mod1,main="Fodder")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataEvar$residuals_fodder <- resids 
Moran.I(DataEvar$residuals_fodder, dist.inv)# zero autocorrelation (p=0.659)


#Medicinal
mod1<-lme(log(Medic)~Land.use + Site, random=~1|plot, data=DataEvar)
plot(mod1,main="Medic")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataEvar$residuals_medic <- resids 
Moran.I(DataEvar$residuals_medic, dist.inv)# zero autocorrelation (p=0.343)



#Meliferous
mod1<-lme(log(Melif)~Land.use + Site, random=~1|plot, data=DataEvar)
plot(mod1,main="Melif")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataEvar$residuals_melif <- resids 
Moran.I(DataEvar$residuals_melif, dist.inv)# zero autocorrelation (p=0.605)


#Nitrogen fixers
mod1<-lme(Nfix~Land.use + Site, random=~1|plot, data=DataEvar)
plot(mod1,main="Nfix")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataEvar$residuals_nfix <- resids 
Moran.I(DataEvar$residuals_nfix, dist.inv)# zero autocorrelation (p=0.887)



#Conservation concern
mod1<-lme(Prot~Land.use + Site, random=~1|plot, data=DataEvar)
plot(mod1,main="Nfix")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataEvar$residuals_prot <- resids 
Moran.I(DataEvar$residuals_prot, dist.inv)# zero autocorrelation (p=0.340)



#Pollen providers
mod1<-lme(log(Pollen)~Land.use + Site, random=~1|plot, data=DataEvar)
plot(mod1,main="Nfix")
qqnorm(mod1, abline=c(0,1))
summary(mod1)
Anova(mod1,type='II',white.adjust=TRUE)# using white.adjust=TRUE, the model is heteroscedasticity-corrected robust ANOVA; the test is a Wald chi-square test;
summary(glht(mod1, linfct = mcp(Land.use="Tukey")))#Tukey test corresponds to Tukey HSD
summary(glht(mod1, linfct = mcp(Site="Tukey")))
resids <- residuals(mod1)
bartlett.test(split(resids,list(Data$Land.use,Data$Site)))#Bartlett test for homogeneity of variances
#check spatial autocorrelation of residuals (Moran's I)
DataEvar$residuals_pollen <- resids 
Moran.I(DataEvar$residuals_pollen, dist.inv)# zero autocorrelation (p=0.946)


dev.off()



#PLOT GRAPHS

#land use effect

#count data
Data<-read.csv("/Users/annamariacsergo/Dropbox/Ecos_Services/Data/Count.csv",stringsAsFactors=FALSE)#read data

Total_countM<-ggplot(Data, aes(Land.use, Total))+
  geom_violin(aes(fill=Land.use), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA)) +stat_summary(fun.y=mean, geom="point", shape=5, size=2) +
  #geom_vline(aes(xintercept=2), col="lightgray")+
  scale_y_continuous(limits = c(20, 50))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks.x = element_blank(),
  axis.line.y = element_line(colour = "black"),
  axis.text.x = element_blank(),
  axis.line.x = element_blank())+
  labs(x=NULL, y = "Species Richness")+
  theme(legend.position="none")
Total_countM

Fodder_count<-ggplot(Data, aes(Land.use, Fodder))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
  #geom_vline(aes(xintercept=2), col="lightgray")+
  scale_y_continuous(limits = c(0, 35))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.text = element_blank(),
  axis.line.x = element_blank(),
  axis.title.y=element_blank())+
  xlab("Fodder")+
  theme(legend.position="none")


Medic_count<-ggplot(Data, aes(Land.use, Medic))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 35))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Medicinal")+
  theme(legend.position="none")

  Honey_count<-ggplot(Data, aes(Land.use, Melif))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 35))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Honey")+
  theme(legend.position="none")

 Nfix_count<-ggplot(Data, aes(Land.use, Nfix))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 35))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Nitrogen")+
  theme(legend.position="none")
  
  Pollen_count<-ggplot(Data, aes(Land.use, Pollen))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 35))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks.x = element_blank(),
  axis.line.y = element_line(colour = "black"),
  axis.line.x = element_blank(),
  axis.text.x = element_blank())+
  labs(x="Pollen", y = "Species Richness")+
  theme(legend.position="none")

Prot_count<-ggplot(Data, aes(Land.use, Prot))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 35))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Conservation")+
  theme(legend.position="none")



#cover data
cover<-read.csv("/Users/annamariacsergo/Dropbox/Ecos_Services/Data/Cover.csv",stringsAsFactors=FALSE)#read data
multiplied<-cover[,2:8]*100
DataCov<-cbind(cover$ID,multiplied,cover$Total,cover$Land.use, cover$Site)
DataCov <- rename (DataCov, c("cover$ID"="ID", "cover$Total"="Total", "cover$Land.use"="Land.use","cover$Site"="Site"))

Total_coverM<-ggplot(DataCov, aes(Land.use, Total))+
  geom_violin(aes(fill=Land.use), lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA)) +stat_summary(fun.y=mean, geom="point", shape=5, size=2) +
  #geom_vline(aes(xintercept=2), col="lightgray")+
  scale_y_continuous(limits = c(50, 105))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks.x = element_blank(),
  axis.line.y = element_line(colour = "black", size=0.5),
  axis.text.x = element_blank(),
  axis.line.x = element_blank())+
  labs(x=NULL, y = "Species Abundance")+
  theme(legend.position="none")
Total_coverM


Fodder_cover<-ggplot(DataCov, aes(Land.use, Fodder))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
  scale_y_continuous(limits = c(0, 100))+
  theme_bw()+
  theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.text = element_blank(),
  axis.line.x = element_blank(),
  axis.title.y=element_blank())+
  xlab("Fodder")+
  theme(legend.position="none")  
  
Medic_cover<-ggplot(DataCov, aes(Land.use, Medic))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 100))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Medicinal")+
  theme(legend.position="none")

  Honey_cover<-ggplot(DataCov, aes(Land.use, Melif))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 100))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Honey")+
  theme(legend.position="none")

 Nfix_cover<-ggplot(DataCov, aes(Land.use, Nfix))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 100))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Nitrogen")+
  theme(legend.position="none")
  
  Pollen_cover<-ggplot(DataCov, aes(Land.use, Pollen))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 100))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks.x = element_blank(),
  axis.line.y = element_line(colour = "black"),
  axis.line.x = element_blank(),
  axis.text.x = element_blank())+
  labs(x="Pollen", y = "Species Abundance")+
  theme(legend.position="none")

Prot_cover<-ggplot(DataCov, aes(Land.use, Prot))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 100))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Conservation")+
  theme(legend.position="none")

#Evenness data
DataEvar<-read.csv("/Users/annamariacsergo/Dropbox/Ecos_Services/Data/Evar.csv",stringsAsFactors=FALSE)#read data

Total_EvarM<-ggplot(DataEvar, aes(Land.use, Total))+
  geom_violin(aes(fill=Land.use), lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA)) +stat_summary(fun.y=mean, geom="point", shape=5, size=2) +
  #geom_vline(aes(xintercept=2), col="lightgray")+
  scale_y_continuous(limits = c(0.1, 0.4))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks.x = element_blank(),
  axis.line.y = element_line(colour = "black", size=0.5),
  axis.text.x = element_blank(),
  axis.line.x = element_blank())+
  labs(x=NULL, y = "Species Evenness")+
  theme(legend.position="none")
Total_EvarM


Fodder_Evar<-ggplot(DataEvar, aes(Land.use, Fodder))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
  scale_y_continuous(limits = c(0, 1.8))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.text = element_blank(),
  axis.line.x = element_blank(),
  axis.title.y=element_blank())+
  xlab("Fodder")+
  theme(legend.position="none")
  
  
Medic_Evar<-ggplot(DataEvar, aes(Land.use, Medic))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 1.8))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Medicinal")+
  theme(legend.position="none")

  Honey_Evar<-ggplot(DataEvar, aes(Land.use, Melif))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 1.8))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Honey")+
  theme(legend.position="none")

 Nfix_Evar<-ggplot(DataEvar, aes(Land.use, Nfix))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 1.8))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Nitrogen")+
  theme(legend.position="none")
  
  Pollen_Evar<-ggplot(DataEvar, aes(Land.use, Pollen))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 1.8))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks.x = element_blank(),
  axis.line.y = element_line(colour = "black"),
  axis.line.x = element_blank(),
  axis.text.x = element_blank())+
  labs(x="Pollen", y = "Species Evenness")+
  theme(legend.position="none")

Prot_Evar<-ggplot(DataEvar, aes(Land.use, Prot))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 1.8))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Conservation")+
  theme(legend.position="none")

#InvSimpson Diversity data
DataSimp<-read.csv("/Users/annamariacsergo/Dropbox/Ecos_Services/Data/InvSimpson.csv",stringsAsFactors=FALSE)#read data

Total_SimpM<-ggplot(DataSimp, aes(Land.use, Total))+
  geom_violin(aes(fill=Land.use), lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA)) +stat_summary(fun.y=mean, geom="point", shape=5, size=2) +
  #geom_vline(aes(xintercept=2), col="lightgray")+
  scale_y_continuous(limits = c(2, 9))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks.x = element_blank(),
  axis.line.y = element_line(colour = "black", size=0.5),
  axis.text.x = element_blank(),
  axis.line.x = element_blank())+
  labs(x=NULL, y = "Species Diversity")+
  theme(legend.position="none")
Total_SimpM


Fodder_Simp<-ggplot(DataSimp, aes(Land.use, Fodder))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
  scale_y_continuous(limits = c(0, 20))+
  theme_bw()+
    theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.text = element_blank(),
  axis.line.x = element_blank(),
  axis.title.y=element_blank())+
  xlab("Fodder")+
  theme(legend.position="none")
  
  
Medic_Simp<-ggplot(DataSimp, aes(Land.use, Medic))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 20))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Medicinal")+
  theme(legend.position="none")

  Honey_Simp<-ggplot(DataSimp, aes(Land.use, Melif))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 20))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Honey")+
  theme(legend.position="none")

 Nfix_Simp<-ggplot(DataSimp, aes(Land.use, Nfix))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 20))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Nitrogen")+
  theme(legend.position="none")
  
  Pollen_Simp<-ggplot(DataSimp, aes(Land.use, Pollen))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 20))+
  theme_bw()+
    theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks.x = element_blank(),
  axis.line.y = element_line(colour = "black"),
  axis.line.x = element_blank(),
  axis.text.x = element_blank())+
  labs(x="Pollen", y = "Species Diversity")+
  theme(legend.position="none")

Prot_Simp<-ggplot(DataSimp, aes(Land.use, Prot))+
  geom_violin(aes(fill=Land.use),lwd=0.3)+
  #geom_violin(aes(fill=Land.use),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Land.use), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("darkgrey","lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 20))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Conservation")+
  theme(legend.position="none")
  
setEPS()
postscript("~/Dropbox/Ecos_Services/SupplementaryMaterial/Providers_LandUse.eps", width= 10,height=14)
pdf("~/Dropbox/Ecos_Services/SupplementaryMaterial/Providers_LandUse.pdf",width=10,height=14)
grid.arrange(Pollen_count, Fodder_count, Medic_count, Honey_count, Nfix_count, Prot_count, Pollen_Evar, Fodder_Evar, Medic_Evar, Honey_Evar, Nfix_Evar, Prot_Evar, Pollen_Simp, Fodder_Simp, Medic_Simp, Honey_Simp, Nfix_Simp, Prot_Simp, Pollen_cover, Fodder_cover, Medic_cover, Honey_cover, Nfix_cover, Prot_cover, ncol=6, nrow=4)
dev.off()



#Site effects


#count data
Data<-read.csv("/Users/annamariacsergo/Dropbox/Ecos_Services/Data/Count.csv",stringsAsFactors=FALSE)#read data

Total_countS<-ggplot(Data, aes(Site, Total))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA)) +stat_summary(fun.y=mean, geom="point", shape=5, size=2) +
  #geom_vline(aes(xintercept=2), col="lightgray")+
  scale_y_continuous(limits = c(20, 50))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks.x = element_blank(),
  axis.line.y = element_line(colour = "black", size=0.5),
  axis.text.x = element_blank(),
  axis.line.x = element_blank())+
  labs(x=NULL, y = "Species Richness")+
  theme(legend.position="none")
Total_countS

Fodder_count<-ggplot(Data, aes(Site, Fodder))+
  geom_violin(aes(fill=Site),lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
  #geom_vline(aes(xintercept=2), col="lightgray")+
  scale_y_continuous(limits = c(0, 35))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.text = element_blank(),
  axis.line.x = element_blank(),
  axis.title.y=element_blank())+
  xlab("Fodder")+
  theme(legend.position="none")
  
  
Medic_count<-ggplot(Data, aes(Site, Medic))+
  geom_violin(aes(fill=Site),lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 35))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Medicinal")+
  theme(legend.position="none")

  Honey_count<-ggplot(Data, aes(Site, Melif))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 35))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Honey")+
  theme(legend.position="none")

 Nfix_count<-ggplot(Data, aes(Site, Nfix))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 35))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Nitrogen")+
  theme(legend.position="none")
  
  Pollen_count<-ggplot(Data, aes(Site, Pollen))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 35))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks.x = element_blank(),
  axis.line.y = element_line(colour = "black"),
  axis.line.x = element_blank(),
  axis.text.x = element_blank())+
  labs(x="Pollen", y = "Species Richness")+
  theme(legend.position="none")

Prot_count<-ggplot(Data, aes(Site, Prot))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 35))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Conservation")+
  theme(legend.position="none")



#cover data
cover<-read.csv("/Users/annamariacsergo/Dropbox/Ecos_Services/Data/Cover.csv",stringsAsFactors=FALSE)#read data
multiplied<-cover[,2:8]*100
DataCov<-cbind(cover$ID,multiplied,cover$Total,cover$Site)
DataCov <- rename (DataCov, c("cover$ID"="ID", "cover$Total"="Total", "cover$Site"="Site"))

Total_coverS<-ggplot(DataCov, aes(Site, Total))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA)) +stat_summary(fun.y=mean, geom="point", shape=5, size=2) +
  #geom_vline(aes(xintercept=2), col="lightgray")+
  scale_y_continuous(limits = c(50, 105))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks.x = element_blank(),
  axis.line.y = element_line(colour = "black", size=0.5),
  axis.text.x = element_blank(),
  axis.line.x = element_blank())+
  labs(x=NULL, y = "Species Abundance")+
  theme(legend.position="none")
Total_coverS



Fodder_cover<-ggplot(DataCov, aes(Site, Fodder))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
  scale_y_continuous(limits = c(0, 100))+
  theme_bw()+
    theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.text = element_blank(),
  axis.line.x = element_blank(),
  axis.title.y=element_blank())+
  xlab("Fodder")+
  theme(legend.position="none")
  
  
Medic_cover<-ggplot(DataCov, aes(Site, Medic))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 100))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Medicinal")+
  theme(legend.position="none")

  Honey_cover<-ggplot(DataCov, aes(Site, Melif))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 100))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Honey")+
  theme(legend.position="none")

 Nfix_cover<-ggplot(DataCov, aes(Site, Nfix))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 100))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Nitrogen")+
  theme(legend.position="none")
  
  Pollen_cover<-ggplot(DataCov, aes(Site, Pollen))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 100))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks.x = element_blank(),
  axis.line.y = element_line(colour = "black"),
  axis.line.x = element_blank(),
  axis.text.x = element_blank())+
  labs(x="Pollen", y = "Species Abundance")+
  theme(legend.position="none")

Prot_cover<-ggplot(DataCov, aes(Site, Prot))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 100))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Conservation")+
  theme(legend.position="none")

#Evenness data
DataEvar<-read.csv("/Users/annamariacsergo/Dropbox/Ecos_Services/Data/Evar.csv",stringsAsFactors=FALSE)#read data

Total_EvarS<-ggplot(DataEvar, aes(Site, Total))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA)) +stat_summary(fun.y=mean, geom="point", shape=5, size=2) +
  #geom_vline(aes(xintercept=2), col="lightgray")+
  scale_y_continuous(limits = c(0.1, 0.37))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks.x = element_blank(),
  axis.line.y = element_line(colour = "black", size=0.5),
  axis.text.x = element_blank(),
  axis.line.x = element_blank())+
  labs(x=NULL, y = "Species Evenness")+
  theme(legend.position="none")
Total_EvarS


Fodder_Evar<-ggplot(DataEvar, aes(Site, Fodder))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
  scale_y_continuous(limits = c(0, 1.8))+
  theme_bw()+
    theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.text = element_blank(),
  axis.line.x = element_blank(),
  axis.title.y=element_blank())+
  xlab("Fodder")+
  theme(legend.position="none")
  
  
Medic_Evar<-ggplot(DataEvar, aes(Site, Medic))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 1.8))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Medicinal")+
  theme(legend.position="none")

  Honey_Evar<-ggplot(DataEvar, aes(Site, Melif))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 1.8))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Honey")+
  theme(legend.position="none")

 Nfix_Evar<-ggplot(DataEvar, aes(Site, Nfix))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 1.8))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Nitrogen")+
  theme(legend.position="none")
  
  Pollen_Evar<-ggplot(DataEvar, aes(Site, Pollen))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 1.8))+
  theme_bw()+
    theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks.x = element_blank(),
  axis.line.y = element_line(colour = "black"),
  axis.line.x = element_blank(),
  axis.text.x = element_blank())+
  labs(x="Pollen", y = "Species Evenness")+
  theme(legend.position="none")

Prot_Evar<-ggplot(DataEvar, aes(Site, Prot))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 1.8))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Conservation")+
  theme(legend.position="none")

#InvSimpson Diversity data
DataSimp<-read.csv("/Users/annamariacsergo/Dropbox/Ecos_Services/Data/InvSimpson.csv",stringsAsFactors=FALSE)#read data


Total_SimpS<-ggplot(DataSimp, aes(Site, Total))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3), shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA)) +stat_summary(fun.y=mean, geom="point", shape=5, size=2) +
  #geom_vline(aes(xintercept=2), col="lightgray")+
  scale_y_continuous(limits = c(2, 9))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks.x = element_blank(),
  axis.line.y = element_line(colour = "black", size=0.5),
  axis.text.x = element_blank(),
  axis.line.x = element_blank())+
  labs(x=NULL, y = "Species Diversity")+
  theme(legend.position="none")
Total_SimpS


Fodder_Simp<-ggplot(DataSimp, aes(Site, Fodder))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
  scale_y_continuous(limits = c(0, 20))+
  theme_bw()+
    theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.text = element_blank(),
  axis.line.x = element_blank(),
  axis.title.y=element_blank())+
  xlab("Fodder")+
  theme(legend.position="none")
  
  
Medic_Simp<-ggplot(DataSimp, aes(Site, Medic))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 20))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Medicinal")+
  theme(legend.position="none")

  Honey_Simp<-ggplot(DataSimp, aes(Site, Melif))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 20))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Honey")+
  theme(legend.position="none")

 Nfix_Simp<-ggplot(DataSimp, aes(Site, Nfix))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 20))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Nitrogen")+
  theme(legend.position="none")
  
  Pollen_Simp<-ggplot(DataSimp, aes(Site, Pollen))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 20))+
  theme_bw()+
  theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks.x = element_blank(),
  axis.line.y = element_line(colour = "black"),
  axis.line.x = element_blank(),
  axis.text.x = element_blank())+
  labs(x="Pollen", y = "Species Diversity")+
  theme(legend.position="none")

Prot_Simp<-ggplot(DataSimp, aes(Site, Prot))+
  geom_violin(aes(fill=Site), lwd=0.3)+
  #geom_violin(aes(fill=Site),outlier.shape=1, outlier.size=1,fatten=0.7,lwd=0.3)+
  geom_jitter(aes(fill=Site), position=position_jitterdodge(jitter.width=0.3),  shape=1, lwd=0.3, col="blue")+
 scale_fill_manual(values=c("lightgray",NA))+stat_summary(fun.y=mean, geom="point", shape=5, size=2) + 
 #geom_vline(aes(xintercept=2), col="lightgray")+
 scale_y_continuous(limits = c(0, 20))+
  theme_bw()+
   theme(
  panel.grid.minor=element_blank(),
  #panel.grid.major = element_line(linetype="longdash"),
  panel.grid.major = element_blank(),
  panel.border = element_blank(),
  axis.ticks = element_blank(),
  axis.line.y = element_blank(),
  axis.line.x = element_blank(),
  axis.text = element_blank(),
  axis.title.y = element_blank())+
  xlab("Conservation")+
  theme(legend.position="none")
  
setEPS()
postscript("~/Dropbox/Ecos_Services/SupplementaryMaterial/Providers_Site.eps", width= 10,height=14)
pdf("~/Dropbox/Ecos_Services/SupplementaryMaterial/Providers_Site.pdf",width=10,height=14)
grid.arrange(Pollen_count, Fodder_count, Medic_count, Honey_count, Nfix_count, Prot_count, Pollen_Evar,Fodder_Evar, Medic_Evar, Honey_Evar, Nfix_Evar, Prot_Evar, Pollen_Simp, Fodder_Simp, Medic_Simp, Honey_Simp, Nfix_Simp, Prot_Simp, Pollen_cover, Fodder_cover, Medic_cover, Honey_cover, Nfix_cover, Prot_cover,  ncol=6, nrow=4)
dev.off()

#Graphs for Total species by management and site
setEPS()
postscript("~/Dropbox/Ecos_Services/SupplementaryMaterial/TotalSpecies_LandUse.eps",width= 10,height=5)
pdf("~/Dropbox/Ecos_Services/SupplementaryMaterial/TotalSpecies_LandUse.pdf",width=10,height=5)
grid.arrange(Total_countM, Total_EvarM, Total_SimpM, Total_coverM, ncol=4, nrow=1, top="Management")
dev.off()

setEPS()
postscript("~/Dropbox/Ecos_Services/SupplementaryMaterial/TotalSpecies_Site.eps",width= 10,height=5)
pdf("~/Dropbox/Ecos_Services/SupplementaryMaterial/TotalSpecies_Site.pdf",width=10,height=5)
grid.arrange(Total_countS, Total_EvarS, Total_SimpS, Total_coverS,  ncol=4, nrow=1, top="Site")
dev.off()



